@@ -18,4 +18,4 @@ def str2bytes(data):
     :param data: string with a byte-sequence in it (example: "ffd8")
     :returns: bytes object of that sequence (example: b"\\xff\\xd8")
     """
-    return bytes( int(a+b, base=16) for a, b in zip(data[::2], data[1::2]))
+    return bytes.fromhex(data)
